@@ -3,16 +3,16 @@
 FedSim
 ------
 
- a simple Federated Learning simulator!
+Comprehensive and flexible Federated Learning Simulator!
 
 """
 
-__version__ = "0.3.0"
+__version__ = "0.7.0"
 
 from . import datasets
 from . import distributed
 from . import local
-from . import lr_schedulers
+from . import losses
 from . import models
 from . import scores
 from . import utils
@@ -22,7 +22,7 @@ __all__ = [
     "distributed",
     "models",
     "local",
-    "lr_schedulers",
     "scores",
+    "losses",
     "utils",
 ]
