@@ -2,23 +2,18 @@
 Step Closures
 -------------
 """
-from functools import partial
 
-import torch
 from torch.nn.utils import clip_grad_norm_
 
-from fedsim.utils import collect_scores
-
 
 def default_step_closure(
     x,
     y,
     model,
-    loss_fn,
+    criterion,
     optimizer,
-    metric_fn_dict,
+    scores,
     max_grad_norm=1000,
-    link_fn=partial(torch.argmax, dim=1),
     device="cpu",
     transform_grads=None,
     transform_y=None,
@@ -26,13 +21,12 @@ def default_step_closure(
 ):
     if transform_y is not None:
         y = transform_y(y)
-    y_true = y.tolist()
     x = x.to(device)
     y = y.reshape(-1).long()
     y = y.to(device)
     model.train()
     outputs = model(x)
-    loss = loss_fn(outputs, y)
+    loss = criterion(outputs, y)
     if loss.isnan() or loss.isinf():
         return loss
     # backpropagation
@@ -44,6 +38,8 @@ def default_step_closure(
     # optimize
     optimizer.step()
     optimizer.zero_grad()
-    y_pred = link_fn(outputs).tolist()
-    metrics = collect_scores(metric_fn_dict, y_true, y_pred)
-    return loss, metrics
+
+    if scores is not None:
+        for score in scores.values():
+            score(outputs, y)
+    return loss
