@@ -6,8 +6,11 @@ andy functions and classes used in FedSim package
 
 """
 
+from .aggregators import AppendixAggregator
 from .aggregators import SerialAggregator
+from .convert_parameters import initialize_module
 from .convert_parameters import vector_to_parameters_like
+from .convert_parameters import vectorize_module
 from .dict_ops import add_dict_to_dict
 from .dict_ops import add_in_dict
 from .dict_ops import append_dict_to_dict
@@ -15,9 +18,11 @@ from .dict_ops import apply_on_dict
 from .dict_ops import reduce_dict
 from .import_utils import get_from_module
 from .random_utils import set_seed
-from .score_utils import collect_scores
+from .storage import Storage
 
 __all__ = [
+    "vectorize_module",
+    "initialize_module",
     "vector_to_parameters_like",
     "add_dict_to_dict",
     "add_in_dict",
@@ -25,7 +30,8 @@ __all__ = [
     "apply_on_dict",
     "reduce_dict",
     "get_from_module",
-    "collect_scores",
     "set_seed",
     "SerialAggregator",
+    "AppendixAggregator",
+    "Storage",
 ]
